==> alfa-sdk-0.1.1.tar.gz: alfa-sdk-0.1.1/alfa_sdk/common/exceptions.py <==
class AlfaError(Exception):
    template = "An unspecified error occurred"

    def __init__(self, **kwargs):
        if "template" in kwargs:
            self.template = kwargs.get("template")

        message = self.template.format(**kwargs)
        Exception.__init__(self, message)
        self.kwargs = kwargs

    def __reduce__(self):
        return _unpickle_exception, (self.__class__, None, self.kwargs)


def _unpickle_exception(exception_class, args=(), kwargs={}):
    return exception_class(*args, **kwargs)


#


class CredentialsError(AlfaError):
    template = "Authentication credentials not found / invalid"


class TokenNotFoundError(CredentialsError):
    template = "Authentication tokens not found"


class AuthenticationError(AlfaError):
    template = "Error encountered during authentication: {error}"


class AuthorizationError(AlfaError):
    template = "Not authorized for request to {url}: {error}"


class RequestError(AlfaError):
    template = "Error encountered during request to {url} ({status}): {error}"


class ResourceError(AlfaError):
    template = "Error encountered for resource {resource}: {error}"


class ResourceNotFoundError(ResourceError):
    template = "Error encountered during resource initialization: Resource not found in ({url})"


class ResourceDeletionError(ResourceError):
    template = "Cannot delete {resource}: {error}"


class UnknownServiceError(AlfaError):
    template = "Unknown service: '{service_name}'. Valid service names are: {known_service_names}"


class ServiceEnvironmentError(AlfaError):
    template = "Environment '{environment}' does not exist for service '{service_name}'"


class SemanticVersionError(AlfaError):
    template = "Version '{version}' does not comply with Semantic Versioning."


class AlfaConfigError(AlfaError):
    template = "{message} ({error})"

==> alfa-sdk-0.1.15.tar.gz: alfa-sdk-0.1.15/alfa_sdk/common/exceptions.py <==
class AlfaError(Exception):
    template = "An unspecified error occurred"
    code = "UNKNOWN_ERROR"
    status = 500

    def __init__(self, **kwargs):
        if "template" in kwargs:
            self.template = kwargs.get("template")

        message = self.template.format(**kwargs)
        Exception.__init__(self, message)
        self.kwargs = kwargs

    def __reduce__(self):
        return _unpickle_exception, (self.__class__, None, self.kwargs)


def _unpickle_exception(exception_class, args=(), kwargs={}):
    return exception_class(*args, **kwargs)


#


class ResourceError(AlfaError):
    template = "Error encountered for resource {resource}: {error}"
    code = "RESOURCE_NOT_FOUND"
    status = 400


class ValidationError(AlfaError):
    template = "Error during validation: {error}"
    code = "VALIDATION_FAILED"
    status = 400


class PermissionError(AlfaError):
    template = "Not authorized: {error}"
    code = "ACCESS_DENIED"
    status = 403


class AuthenticationError(AlfaError):
    template = "Error encountered during authentication: {error}"
    code = "INVALID_TOKEN"
    status = 401


class AuthorizationError(PermissionError):
    template = "Not authorized for request to {url}: {error}"
    code = "UNAUTHORIZED"
    status = 401


class RequestError(AlfaError):
    template = "Error encountered during request to {url} ({status}): {error}"
    code = "REQUEST_FAILED"


#


class ResourceNotFoundError(ResourceError):
    template = "Resource not found in {url}: {error}"


class ResourceDeletionError(ValidationError):
    template = "Cannot delete {resource}: {error}"


class CredentialsError(ValidationError):
    template = "Authentication credentials not found / invalid"


class TokenNotFoundError(CredentialsError):
    template = "Authentication tokens not found"


class UnknownServiceError(ValidationError):
    template = "Unknown service: '{service_name}'. Valid service names are: {known_service_names}"


class ServiceEnvironmentError(ValidationError):
    template = "Environment '{environment}' does not exist for service '{service_name}'"


class SemanticVersionError(ValidationError):
    template = "Version '{version}' does not comply with Semantic Versioning."


class AlfaConfigError(ValidationError):
    template = "{message} ({error})"
